# @summary Installs and configures sudo
#
# @example
#   include sudo
# @param install_package
#   Determines if package for sudo should be installed.
# @param package_name
#   The name of the package to install.
# @param package_ensure
#   What value for 'ensure' to pass to resource type package.
# @param package_provider
#   Override the default package provider.
# @param sudoers
#   The main configuration file for the sudoers plugin.
# @param manage_sudoers
#   Don't manage the primary sudoers file is this is false.
# @param includedir
#   The dropin directory for additional config files.
# @param purge_includedir
#   Purge any files in $includedir not explicitly managed by this class.
# @param includedir_mode
#   The filemode for the includedir
# @param defaultmode
#   The mode for creates files in includedir.
# @param owner
#   The owner for sudo configfiles.
# @param group
#   The group for sudo configfiles.
# @param use_includedir
#   Add entry for includedir to main sudoer file if true.
class sudo (
  Boolean $install_package           = true,
  String[1] $package_name            = 'sudo',
  String[1] $package_ensure          = 'present',
  Optional[String] $package_provider = undef,
  Stdlib::Unixpath $sudoers          = '/etc/sudoers',
  Boolean $manage_sudoers            = true,
  Stdlib::Unixpath $includedir       = '/etc/sudoers.d',
  Boolean $purge_includedir          = false,
  Stdlib::Filemode $includedir_mode  = '750',
  Stdlib::Filemode $defaultmode      = '440',
  String[1] $owner                   = 'root',
  String[1] $group                   = 'root',
  Boolean $use_includedir            = true,
  Hash[String,Hash[String,Optional[Any]]] $conf = undef,
) {
  contain sudo::config
  if $install_package {
    contain sudo::install
    Class['sudo::install']
    -> Class['sudo::config']
  }
}
